<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr_BE">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>Accès administrateur•rice nécessaire</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Cette opération nécessite des privilèges d’administrateur•rice. Veuillez redémarrer l’application et saisir votre mot de passe lorsque vous y êtes invité.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../src/dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Environnement live détecté. Choisissez la partition root du système
que vous souhaitez modifier (seules les partitions Linux sont affichées)</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Utiliser une interface simple de menu sans sous-menus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Utiliser des menus plats (pas de sous-menus)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Démarrer sur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Régler sur « 0 » pour démarrer immédiatement sans afficher le menu, ou sur « -1 » pour attendre indéfiniment</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Durée du menu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Paramètres du noyau</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>En activant cette option, l’entrée choisie depuis le menu de démarrage grub sera sauvegardée et activée par défaut pour les prochains démarrages</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Activer la sauvegarde du dernier choix de démarrage</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Gérer les options de démarrage UEFI</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Arrière-plan</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="181"/>
        <location filename="../src/mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Activer le thème</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Écran d’accueil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Très détaillé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Détaillé (réglage par défaut)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limité</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Afficher le journal</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>À propos …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>Still running</source>
        <translation>Opération toujours en cours</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="391"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installation de l’écran d’amorçage, veuillez patienter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <location filename="../src/mainwindow.cpp" line="1188"/>
        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
        <translation>L’aperçu est désactivé car le paramètre « splash » n’est pas présent dans la ligne de commande du noyau. Pour activer l’aperçu, ajoutez « splash » aux paramètres de démarrage et redémarrez.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="161"/>
        <location filename="../src/mainwindow.cpp" line="1191"/>
        <source>Preview is disabled while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation>L’aperçu est désactivé sous Wayland. Veuillez démarrer une session X11 pour prévisualiser les thèmes Plymouth.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Updating sources</source>
        <translation>Mise à jour des sources</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <source>Could not install the bootsplash.</source>
        <translation>L’écran d’amorçage n’a pas pu être installé.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <source>Could not create a temporary folder</source>
        <translation>Impossible de créer un dossier temporaire</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <location filename="../src/mainwindow.cpp" line="584"/>
        <source>Cannot continue</source>
        <translation>Impossible de continuer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>Impossible d’ouvrir le périphérique LUKS. Arrêt du processus …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="585"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Impossible de créer environnement chroot, impossible de modifier les options de démarrage. Arrêt du processus …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="917"/>
        <location filename="../src/mainwindow.cpp" line="1315"/>
        <source>Updating configuration, please wait</source>
        <translation>Mise à jour de la configuration, veuillez patienter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="988"/>
        <source>Updating initramfs...</source>
        <translation>Mise à jour d’initramfs …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1002"/>
        <location filename="../src/mainwindow.cpp" line="1330"/>
        <source>Updating grub...</source>
        <translation>Mise à jour de grub …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1027"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1028"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1030"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programme pour définir les options de démarrage courantes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1032"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1033"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1054"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1064"/>
        <location filename="../src/mainwindow.cpp" line="1292"/>
        <source>Running in a Virtual Machine</source>
        <translation>Lancer dans une machine virtuelle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1065"/>
        <location filename="../src/mainwindow.cpp" line="1293"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Votre système actuel fonctionne dans une Machine Virtuelle,
L’écran d’amorçage Plymouth fonctionnera de façon restreinte, vous ne pourrez pas non plus prévisualiser le thème</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1072"/>
        <source>Plymouth packages not installed</source>
        <translation>Les paquets pour Plymouth ne sont pas installés</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1073"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Les paquets Plymouth ne sont pas installés actuellement.
Voulez-vous les installer?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1099"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Images (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Log not found</source>
        <translation>Journal introuvable</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Could not find log at </source>
        <translation>Impossible de trouver le journal dans </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1274"/>
        <source>Preview Unavailable</source>
        <translation>Aperçu indisponible</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1275"/>
        <source>Preview is not available while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation>L’aperçu n’est pas disponible sous Wayland. Veuillez démarrer une session X11 pour prévisualiser les thèmes Plymouth.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Impossible de récupérer l’UUID pour %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1407"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Entrer le mot de passe pour déverrouiller la partition chiffrée %1:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>Saisie du mot de passe annulée ou vide pour %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Impossible d’ouvrir le conteneur LUKS %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1242"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="101"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Un processus est toujours en cours. Voulez-vous vraiment arrêter?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="181"/>
        <source>Live System Detected</source>
        <translation>Détection d’un système Live</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Vous utilisez actuellement un système Live. Souhaitez-vous modifier les options de démarrage pour le système Live ou pour un système installé?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Live System</source>
        <translation>Système Live</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Installed System</source>
        <translation>Système installé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <source>Failed to update package sources.</source>
        <translation>Impossible de mettre à jour les sources du paquet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="406"/>
        <source>Installing packages:</source>
        <translation>Installation des paquets:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Bootsplash a été installé correctement.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <source>Failed to create temporary file.</source>
        <translation>Impossible de créer un fichier temporaire.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1010"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Vous êtes actuellement en mode Live avec l’option « toram ». N’oubliez pas de sauvegarder le fichier de persistance ou de remasteriser, sinon toutes les modifications apportées seront perdues.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1012"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Vos modifications ont été appliquées avec succès.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1013"/>
        <source>Operation Complete</source>
        <translation>L’opération est terminée</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1098"/>
        <source>Select image to display in bootloader</source>
        <translation>Choisir l’image à afficher pour le chargeur de démarrage</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1234"/>
        <source>Boot Log</source>
        <translation>Journal de démarrage</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1281"/>
        <source>Needs reboot</source>
        <translation>Redémarrage requis</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1282"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth vient d’être installé, vous devrez probablement redémarrer avant de pouvoir afficher les aperçus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1355"/>
        <source>Click to select theme</source>
        <translation>Cliquez pour sélectionner le thème</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1366"/>
        <source>Select GRUB theme</source>
        <translation>Choisir le thème de GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programme pour définir les options de démarrage courantes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="55"/>
        <location filename="../src/about.cpp" line="64"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur•rice normal•e pour utiliser ce programme.</translation>
    </message>
</context>
</TS>